"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@collectable/core");
const internals_1 = require("../internals");
function get(key, tree) {
    var node = tree._root, compare = tree._compare, found = false, value;
    do {
        if (internals_1.isNone(node)) {
            found = true;
        }
        else {
            var c = compare(key, node.key);
            if (c === 0) {
                value = node.value;
                found = true;
            }
            else if (c > 0) {
                node = node._right;
            }
            else {
                node = node._left;
            }
        }
    } while (!found);
    return value;
}
exports.get = get;
/**
 * Determines whether or not a given key exists in the tree
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {K} key The key to look for
 * @param {RedBlackTree<K, V>} tree The input tree
 * @returns {boolean} True if the there is an entry for the specified key, otherwise false
 */
function has(key, tree) {
    return core_1.isDefined(get(key, tree));
}
exports.has = has;
function iterateFromKey(reverse, key, tree) {
    const path = internals_1.findPathToNodeByKey(key, tree._root, tree._compare);
    return new internals_1.RedBlackTreeIterator(path, reverse);
}
exports.iterateFromKey = iterateFromKey;

//# sourceMappingURL=get.js.map
